# zoo-frontend（大报告要求）

本次建设的动物信息分为以下功能：

1. 数据录入与管理（前端基本完成，已接入后端）
   系统应提供数据录入功能，允许用户输入动物的基本信息，如种类、年龄、性别、体重、健康状况等。同时，系统应具备数据管理功能，包括数据的查询、修改、删除等操作，以便用户能够方便地管理和维护动物信息。

2. 动物档案管理（前端基本完成，已接入后端）
   系统应建立动物档案，记录动物的整个生命周期，包括出生日期、疫苗接种记录、疾病治疗记录、饲养记录等。这有助于跟踪动物的健康状况和饲养情况，为动物提供更好的管理和照顾。

3. 饲养管理（前端基本完成，已接入后端）
   系统应提供饲养管理功能，包括饲养计划的制定、饲养任务的分配、饲养记录的管理等。这有助于确保动物获得适当的饲料和营养，保持健康生长。

4. 健康监测与预警（前端基本完成，已接入后端）
   系统应具备健康监测功能，定期收集和分析动物的健康数据，如体温、心率、呼吸频率等。同时，系统应提供预警功能，当动物的健康数据出现异常时，及时提醒管理人员采取相应措施。

5. 统计分析（前端基本完成，无需后端）
   系统应提供统计分析功能，对动物信息、饲养记录、健康数据等进行统计分析，生成各类报表和图表。这有助于管理人员了解动物的整体状况和饲养效果，为决策提供支持。

6. 用户权限管理（前端基本完成，已接入后端）
   系统应建立用户权限管理机制，对不同用户设置不同的权限，如管理员、饲养员、兽医等。这有助于确保系统的安全性和数据的保密性。

使用的技术/资源：

- vue3
- ElementUI
- axios

# 说明（给使用者看的）

## 功能说明

首页统计面板没有对接后端，无法操作，只做观赏作用

其余界面均实现基本的增删改查，健康监测等复杂的功能没有实现

## 使用说明

前端方面：下载zip或通过git拉取文件运行

后端方面：同上，但是application.yml中的username和password需要改成你自己数据库的用户名和密码，一般只需要改密码就行，还有其他项目配置如jdk，maven需要你自己配置

数据库方面：先创建一个数据库（无需建表），数据库名字为zoo，然后运行sql文件导入表和数据

前端需要搞好数据库和运行后端程序，才能正常运行使用

# 需要后端提供的数据（给后端开发看的）

一切以最终实现的接口为准，你需要前端提供什么数据就什么数据

## 登录功能

前端提供参数

```json
{
  "user": {
    "username": "user1",
    "password": "123456"
  }
}
```

需要后端返回标识用户身份的数据，012代表三种用户身份

最少需要的数据有：
用户名、身份标识

## 用户管理功能
---

### 用户查询

前端提供：一个用户id或者不提供，提供id就返回单个用户，不提供就返回所有用户

若成功，返回所有用户的结果集（节省时间不搞分页了）

### 用户添加

前端提供的数据一个用户对象

后端添加该对象进数据库

后端返回状态码，哪个码表示什么意思记得写一下

### 用户删除

前端提供：要删除的用户id

后端删除对应的用户返回结果

### 用户编辑
前端提供：一个用户对象

后端修改对应的用户返回结果

## 动物信息管理功能
---

### 动物查询

前端提供的数据，动物id或者不提供

后端返回单个动物或所有动物

### 动物添加

前端提供数据：一个动物对象

后端添加该对象返回操作结果

### 动物删除

前端提供：动物id

后端删除对应的动物，返回结果

### 动物编辑

前端提供：一个动物对象

后端修改对应的动物返回结果

## 饲养管理
---

需要后端创建一个饲养计划表，为了节省时间不需要设置外键什么的,参考如下
```
breedingPlan: {
        id: '',//int 饲养计划id
        name: '',//字符 饲养计划名称
        species: '',//字符 种类
        sex: '雄性',//字符 饲养动物性别
        phase: '',//字符 饲养动物生长阶段：幼年期、成长期、成年期、老年期
        state: 0,//int 状态（0正常 1异常）
        roleId: 1,//负责执行计划的饲养员id
        describe: ''//字符 饲养计划的描述
      }
```

### 饲养计划查询

前端提供：饲养计划id或者不提供

后端返回单个饲养计划或所有饲养计划

### 饲养计划添加

前端提供：一个饲养计划对象

后端添加该对象并返回操作结果

### 饲养计划删除

前端提供：饲养计划id

后端删除该饲养计划并返回操作结果

### 饲养计划修改

前端提供：一个饲养计划对象

后端添加该对象并返回操作结果

## 档案管理
---
需要后端创建一个档案记录表，参考属性如下
```
archive:{
            id: 1,//int 档案号
            animalId: 1,//int 该档案记录的动物id
            animalName: 'animal1',//字符 该档案记录的动物名称
            phase:'幼年期',//字符 该档案记录的动物生命阶段
            state:0,//int 动物状态 0正常，1异常 
            type:'日常饲养',// 字符 档案的类型，分为疫苗接种、疾病治疗、日常饲养
            date:'2024-06-01',//字符 档案记录日期
            time:'18:30:00',//字符，档案记录时间，时分秒
            roleId: 1,//负责录入档案的人的id，身份不限
            description: '描述',//字符 档案的描述
        }
```

### 档案查询

前端提供档案号、动物id、或者不提供

当提供档案号时，返回符合的一条档案
当提供动物id时，返回符合动物id的多条档案
当不提供时，返回所有档案

### 档案删除

前端提供档案号，后端删除并返回结果

### 档案添加

前端提供一个档案对象，后端进行添加

### 档案修改

前端提供一个档案对象，后端进行修改

## 健康检测
---
需要后端创建一个健康检测记录表，参考属性如下
```
health: {
        id: 1,//int 健康检测数据号
        animalId: 1,//int 记录的动物id
        animalName: 'animal',//字符 记录的动物名称
        state: 0,//int 动物状态 0正常，1异常
        temperature:36.5,//double 体温
        breathRate:15,//int 呼吸频率
        heartRate:72,//int 心跳频率
        bloodPressure:90,//int // 血压
        date: '2024-06-01',//字符 记录日期
        time: '18:00:00',//字符，记录时间
        description: '无异常',//字符 检测的描述，比如动物的症状
      },
```

### 健康数据查询

前端提供档健康检测数据号、动物id、或者不提供

当提供健康检测数据号时，返回符合的一条档案
当提供动物id时，返回符合动物id的多条健康检测数据
当不提供时，返回所有健康检测数据

### 健康数据删除

前端提供健康检测数据号，后端删除并返回结果

### 健康数据添加

前端提供健康检测数据对象，后端进行添加

### 健康数据修改

前端提供健康检测数据对象，后端进行修改

## 统计分析
---
无需后端
