import { createRouter } from "vue-router";
import { createWebHashHistory } from "vue-router";

import ZooLogin from '@/pages/ZooLogin.vue'
import ZooPanel from "@/pages/ZooPanel.vue";
import ZooHome from '@/pages/ZooHome.vue'
import ZooUser from "@/pages/ZooUser.vue";
import ZooAnimal from "@/pages/ZooAnimal.vue";
import store from "@/store/index.js";
import ZooBreeding from "@/pages/ZooBreeding.vue";
import ZooArchive from "@/pages/ZooArchive.vue";
import ZooData from "@/pages/data.vue";
import ZooHealth from "@/pages/ZooHealth.vue";

const router = createRouter({
    history: createWebHashHistory(),
    routes: [
        {
            // 重定向至面板主页
            path: '/',
            redirect: '/login'
        },
        {
            path: '/login',
            component: ZooLogin
        },
        {
            path: '/panel',
            redirect: '/panel/home'
        },
        {
            path: '/panel',
            component:ZooPanel,
            // meta:{isAuth: true},//需要权限
            children:[
                {
                    path: 'home',
                    component: ZooHome,
                    // meta:{isAuth: true},//需要权限
                },
                {
                    path:'user',
                    component:ZooUser,
                    // meta:{isAuth: true},//需要权限
                },
                {
                    path:'animal',
                    component:ZooAnimal,
                    // meta:{isAuth: true},//需要权限
                },
                {
                    path:'breeding',
                    component:ZooBreeding,
                    // meta:{isAuth: true},//需要权限
                },
                {
                    path:'archive',
                    component:ZooArchive,
                },
                {
                    path:'health',
                    component:ZooHealth,
                }
            ]
        },
        {
            path:'/data',
            component:ZooData
        }

    ]
})

router.beforeEach((to, from, next) => {
    //判断页面是否需要登录权限才可进入
    //不是登录界面都需要权限。。。
    // console.log(to, from, next);
    if (to.path !== '/login') {
        if (to.path==='/data'){
            next()
        }else if (!store.state.loginUser.username) {
            router.replace({
                path: '/login',
            })
        }else next()
    } else {
        next()
    }
})



export default router