import {createStore} from "vuex";
import {copy} from "@/utils/common.js";
import request, {
    frontendAnimals,
    frontendArchives,
    frontendBreedingPlans,
    frontendHealths,
    frontendUsers
} from "@/utils/request.js";

const actions = {
    //获取用户数据
    getUsers(context) {
        console.log('getUsers')
        //通过后端获取数据
        request.queryUserRequest().then(response => {
            if (response.data.code === 1) {
                context.commit('updateUsers', frontendUsers(response.data.data));
            }
        })
    },
    //获取动物数据
    getAnimals(context) {
        console.log('getAnimals')
        // 通过后端获取数据
        request.queryAnimalRequest().then(response => {
            if (response.data.code === 1) {
                context.commit('updateAnimals', frontendAnimals(response.data.data));
            }
        })
    },
    //获取饲养计划
    getBreedingPlans(context) {
        console.log('getBreedingPlans')
        // 通过后端获取数据
        request.queryBreedingPlanRequest().then(response => {
            if (response.data.code === 1) {
                context.commit('updateBreedingPlans',frontendBreedingPlans(response.data.data));
            }
        })
    },
    //获取动物档案
    getArchives(context) {
        console.log('getArchives')
        // 通过后端获取数据
        request.queryArchiveRequest().then(response => {
            if (response.data.code === 1) {
                context.commit('updateArchives',frontendArchives(response.data.data));
            }
        })
    },

    //获取监控检测数据
    getHealths(context) {
        console.log('getHealths')
        // 通过后端获取数据
        request.queryHealthRequest().then(response => {
            if (response.data.code === 1) {
                context.commit('updateHealths',frontendHealths(response.data.data));
            }
        })
    }
}

const mutations = {
    //更新已登录的用户
    updateLoginUser(state, value) {
        state.loginUser = value
    },
    //更新用户集合
    updateUsers(state, value) {
        state.users = value

        //复制一份给前端表格展示，不轻易修改源数据
        state.usersTableData = copy(state.users)
    },
    updateUsersTableData(state, value) {
        state.usersTableData = value
    },

    //更新动物集合
    updateAnimals(state, value) {
        state.animals = value

        //复制一份给前端表格展示，不轻易修改源数据
        state.animalsTableData = copy(state.animals)
    },
    updateAnimalsTableData(state, value) {
        state.animalsTableData = value
    },

    //更新饲养计划
    updateBreedingPlans(state, value) {
        state.breedingPlans = value

        //复制一份给前端表格展示，不轻易修改源数据
        state.breedingPlansTableData = copy(state.breedingPlans)
    },
    updateBreedingPlansTableData(state, value) {
        state.breedingPlansTableData = value
    },

    //更新动物档案
    updateArchives(state, value) {
        state.archives = value

        //复制一份给前端表格展示，不轻易修改源数据
        state.archivesTableData = copy(state.archives)
    },
    updateArchivesTableData(state, value) {
        state.archivesTableData = value
    },

    //更新健康检测
    updateHealths(state, value) {
        state.healths = value

        //复制一份给前端表格展示，不轻易修改源数据
        state.healthsTableData = copy(state.healths)
    },
    updateHealthsTableData(state, value) {
        state.healthsTableData = value
    }
}

const state = {
    //登录用户数据
    loginUser: {
        id:0,
        username: '',
        auth: 0
    },
    //用户数据
    users: [],
    usersTableData:[],//用户表格数据
    //动物数据
    animals: [],
    animalsTableData:[],//动物表格数据
    //饲养计划
    breedingPlans:[],
    breedingPlansTableData:[],//饲养计划表格数据
    //动物档案
    archives:[],
    archivesTableData:[],//动物档案表格数据
    //健康检测
    healths:[],
    healthsTableData:[],//健康检测表格数据
}

const getters = {
    getKeepers() {
        const k = []
        state.users.forEach(user => {
            if (user.auth === 1){
                k.push(copy(user))
            }
        })
        return k;
    },
    getAllSpecies() {
        const set = new Set
        state.animals.forEach(e => {
            set.add(e.species)
        })
        return set
    },
    getKeepersAndVeterinary() {
        const ka = []
        state.users.forEach(user => {
            if (user.auth === 1 || user.auth === 2){
                ka.push(copy(user))
            }
        })
        return ka
    }
}

export default createStore({
    actions,
    mutations,
    state,
    getters
})